@@ -5,6 +5,7 @@ Utility functions for testing.
 from os import path
 
 import uwhoisd
+from uwhoisd.utils import make_config_parser
 
 
 HERE = path.dirname(__file__)
@@ -12,8 +13,8 @@ HERE = path.dirname(__file__)
 
 def create_uwhois():
     """Prepare a UWhois object for testing."""
-    parser = uwhoisd.make_default_config_parser()
-    parser.read(path.join(HERE, '..', 'uwhoisd.ini'))
+    config = path.join(HERE, '..', 'extra', 'uwhoisd.ini')
+    parser = make_config_parser(uwhoisd.CONFIG, config)
     uwhois = uwhoisd.UWhois()
     uwhois.read_config(parser)
     return uwhois
